# BNOP

BNOP is a reference library containing the code for the BNOP Domain (BORO Native Objects (Python)).

**This project is currently closed, but may be sporadically updated by the BORO Development Team in the future.**

## Execution

* This code is a library, so not to be run on its own.

## Usage Examples

For examples see usages in the following projects:

* https://github.com/boro-alpha/bclearer_boson_1_1.git

## Documentation

#### Background

The Agile Manifesto prefers “working software over comprehensive documentation”. Robert C. Martin, one of the original authors of the Agile Manifesto, is also the author of the book Clean Code.

In this book, he makes a strong case for code being self-documenting: saying things such as "always try to explain yourself in code."

He suggests that the goal of every programmer should be to write code so clean and expressive that code comments are unnecessary.

When a programmer writes a comment, it will usually mean that they have failed to write code that was expressive enough. At the extreme, he suggests, maybe a little rhetorically, that "comments are always failures".

#### The BORO documentation policy

To aim to write code so clean and expressive that code comments are unnecessary.

## Contributing

This package doesn't allow external contributors.

## Liability and Warranty

This code is provided as-is and without warranty.

Under no circumstances will the developers be liable for any incidental, consequential, or indirect damages including but not limited to lost or damaged data, revenue loss, economic loss, or commercial loss arising out of the use of this code.

## License

[MIT](https://choosealicense.com/licenses/mit/)

## Acknowledgements

This work was developed initially by BORO Solutions (https://www.borosolutions.net/) and has been updated as part of the Information Management Framework to support the [National Digital Twin programme](https://www.cdbb.cam.ac.uk/what-we-do/national-digital-twin-programme), and funded by [Department for Business, Energy & Industrial Strategy](https://www.gov.uk/government/organisations/department-for-business-energy-and-industrial-strategy) through the Centre for the Protection of National Infrastructure.
